/******************************************************************************
 J2DPlotLibVersion.h

	Defines current version of J2DPlot library

	Copyright © 1999 by John Lindal. All rights reserved.

 ******************************************************************************/

#ifndef _H_J2DPlotLibVersion
#define _H_J2DPlotLibVersion

// These have to be #defined so they can be used for conditional compilation.

#define CURRENT_J2DPLOT_MAJOR_VERSION	0
#define CURRENT_J2DPLOT_MINOR_VERSION	6
#define CURRENT_J2DPLOT_PATCH_VERSION	5

// This is mainly provided so programmers can see the official version number.

static const char* kCurrentJCoreLibVersionStr = "0.6.5";

// version 0.6.3:
//	*** Increment version numbers of all files that store plot setup information.
//	JX2DPlotWidget:
//		Fixed PWXRead/WriteSetup() to include a version number.
//		Saves itsPSPrintName as part of setup.
//	JXCursorMarkTableDir:
//		Fixed Read/WriteSetup() to include a version number.

// version 0.6.0:
// J2DPlotWidget
//		Added MoveCursor().
//		Added Print() from J2DPlotWidget.  Now takes JPagePrinter instead of
//			JPSPrinter.
//		PWGetWidth/Height() are no longer virtual.  Instead, they call
//			PWGetGUIWidth/Height() (which are virtual) if not printing.
//		Created pure virtual PrintMarks().
//		Made PWDraw() virtual and added const JRect& argument.
//		Mouse cursor now changes when it is over a plot cursor.
//		Plot cursors no longer move when the plot is zoomed.
//		No longer redraws plot while dragging if the cursor itself didn't move.
//		Always saves cursor positions, even if the cursors are not visible.
//		Fixed clipping so cursor values are displayed at bottom of the widget.
//		Fixed clipping so bottom and right pixels are not lost on plot.
//		PWRead/WriteSetup() is no longer virtual.  Call PWXRead/WriteSetup() in
//			JX2DPlotWidget.
// JX2DPlotWidget:
//		Renamed DrawMarks() to PrintMarks() to avoid conflict with
//			J2DPlotWidget::DrawMarks().
//		Moved Print() to J2DPlotWidget.
//		Removed JX2DPlotWidget::DrawContents() and made PWDraw() virtual instead.
//		Created PWXRead/WriteSetup().
// JXCursorMarkTable:
//		Changed prototype of TableDrawArea() to avoid hiding partial page flag
//			inside rect argument.
// JXPlotRangeDialog:
//		When opened, displays current range, if any.
//		Added Clear button to clear the range and close the dialog.

#endif
