/******************************************************************************
 JXPlotRangeDialog.h

	Interface for the JXPlotRangeDialog class

	Copyright @ 1999 by Glenn W. Bach. All rights reserved.

 ******************************************************************************/

#ifndef _H_JXPlotRangeDialog
#define _H_JXPlotRangeDialog

#include <JXDialogDirector.h>

class JXTextButton;
class JXFloatInput;
class JXStaticText;

class JXPlotRangeDialog : public JXDialogDirector
{
	
public:

	JXPlotRangeDialog(JXWindowDirector* supervisor, const JFloat xMax, 
						const JFloat xMin, const JFloat yMax, 
						const JFloat yMin);

	virtual ~JXPlotRangeDialog();
	
	JBoolean GetRangeValues(JFloat* xMax, JFloat* xMin, 
							JFloat* yMax, JFloat* yMin);

protected:

	virtual void	Receive(JBroadcaster* sender, const Message& message);

private:

	JBoolean		itsClearRangeFlag;
	JXTextButton*	itsClearButton;

// begin JXLayout

    JXFloatInput* itsXMin;
    JXFloatInput* itsXMax;
    JXFloatInput* itsYMin;
    JXFloatInput* itsYMax;

// end JXLayout

private:

	void	BuildWindow();

	// not allowed

	JXPlotRangeDialog(const JXPlotRangeDialog& source);
	const JXPlotRangeDialog& operator=(const JXPlotRangeDialog& source);
};

#endif
