/******************************************************************************
 JXPlotLabelDialog.h

	Interface for the JXPlotLabelDialog class

	Written by John Lindal.

 ******************************************************************************/

#ifndef _H_JXPlotLabelDialog
#define _H_JXPlotLabelDialog

#include <JXDialogDirector.h>
#include <J2DPlotWidget.h>

class JString;
class JXInputField;
class JXFontNameMenu;
class JXFontSizeMenu;

class JXPlotLabelDialog : public JXDialogDirector
{
public:

	JXPlotLabelDialog(JXWindowDirector* supervisor, const JString& title,
						const JString& xLabel, const JString& yLabel,
						const JString& font, const JSize size,
						const J2DPlotWidget::LabelSelection selection);

	virtual ~JXPlotLabelDialog();
	
	void 			GetLabels(JString* title, JString* xLabel, JString* yLabel) const;
	const JString&	GetFontName() const;
	JSize			GetFontSize() const;

	virtual void	Activate();

private:

	J2DPlotWidget::LabelSelection itsSelection;

// begin JXLayout

    JXInputField*  itsPlotTitle;
    JXInputField*  itsXAxisLabel;
    JXInputField*  itsYAxisLabel;
    JXFontNameMenu* itsFontMenu;
    JXFontSizeMenu* itsSizeMenu;

// end JXLayout

private:

	void	BuildWindow();

	// not allowed

	JXPlotLabelDialog(const JXPlotLabelDialog& source);
	const JXPlotLabelDialog& operator=(const JXPlotLabelDialog& source);
};

#endif
