/******************************************************************************
 JXCursorMarkTableDir.h

	Interface for the JXCursorMarkTableDir class

	Copyright © 1997 by Glenn Bach. 

 ******************************************************************************/

#ifndef _H_JXCursorMarkTableDir
#define _H_JXCursorMarkTableDir

#include <JXWindowDirector.h>

class J2DPlotWidget;
class JXTextButton;
class JXCursorMarkTable;

class JXCursorMarkTableDir : public JXWindowDirector
{
public:

	JXCursorMarkTableDir(JXWindowDirector* supervisor, J2DPlotWidget* plot);

	virtual ~JXCursorMarkTableDir();

	JXCursorMarkTable*	GetTable();
	virtual void		ReadSetup(istream& input);	
	virtual void		WriteSetup(ostream& output) const; 

protected:

	virtual void		Receive(JBroadcaster* sender,
								const JBroadcaster::Message& message);
private:

	JXTextButton*		itsCloseButton;
	JXCursorMarkTable*	itsTable;
	
private:

	// not allowed

	JXCursorMarkTableDir(const JXCursorMarkTableDir& source);
	const JXCursorMarkTableDir& operator=(const JXCursorMarkTableDir& source);
};

/******************************************************************************
 GetTable

 ******************************************************************************/

inline JXCursorMarkTable*
JXCursorMarkTableDir::GetTable()
{
	return itsTable;
}

#endif
